==> idp-plugin-duo-impl-0.9.0-sources.jar: net/shibboleth/idp/plugin/authn/duo/impl/DuoAudienceClaimLookupStrategy.java <==
/* 
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.shibboleth.idp.plugin.authn.duo.impl;

import java.util.function.BiFunction;

import javax.annotation.Nonnull;

import org.opensaml.profile.context.ProfileRequestContext;

import com.nimbusds.jwt.JWTClaimsSet;

import net.shibboleth.idp.authn.context.AuthenticationContext;
import net.shibboleth.idp.plugin.authn.duo.DuoOIDCIntegration;
import net.shibboleth.idp.plugin.authn.duo.context.DuoOIDCAuthenticationContext;

/**
 * Looks up the audience from the clientID in the {@link DuoOIDCIntegration} inside the context.
 * Returns null if it fails to find the clientID. Used for JWT ID Token audience claims verification.
 */
public class DuoAudienceClaimLookupStrategy implements BiFunction<ProfileRequestContext, JWTClaimsSet, String> {

    /** {@inheritDoc} */
    @Override public String apply(@Nonnull final ProfileRequestContext context,
            @Nonnull final JWTClaimsSet cliams) {
        
        final AuthenticationContext authnContext = context.getSubcontext(AuthenticationContext.class);
        if (authnContext == null) {
            return null;
        }

        final DuoOIDCAuthenticationContext duoContext = authnContext.getSubcontext(DuoOIDCAuthenticationContext.class);
        if (duoContext == null) {
            return null;
        }
        
        final DuoOIDCIntegration duoIntegration = duoContext.getIntegration();
        if (duoIntegration == null) {
            return null;
        }
        return duoIntegration.getClientId();
    }

}

==> idp-plugin-duo-impl-1.4.1-sources.jar: net/shibboleth/idp/plugin/authn/duo/impl/DuoAudienceClaimLookupStrategy.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.shibboleth.idp.plugin.authn.duo.impl;

import java.util.function.BiFunction;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.annotation.concurrent.ThreadSafe;

import org.opensaml.profile.context.ProfileRequestContext;

import com.nimbusds.jwt.JWTClaimsSet;

import net.shibboleth.idp.authn.context.AuthenticationContext;
import net.shibboleth.idp.plugin.authn.duo.DuoOIDCIntegration;
import net.shibboleth.idp.plugin.authn.duo.context.DuoOIDCAuthenticationContext;

/**
 * Looks up the audience from the clientID in the {@link DuoOIDCIntegration} inside the context.
 * Returns null if it fails to find the clientID. Used for JWT ID Token audience claims verification.
 */
@ThreadSafe
public final class DuoAudienceClaimLookupStrategy implements BiFunction<ProfileRequestContext, JWTClaimsSet, String> {

    @Override @Nullable public String apply(@Nonnull final ProfileRequestContext context,
            @Nonnull final JWTClaimsSet cliams) {
        
        final AuthenticationContext authnContext = context.getSubcontext(AuthenticationContext.class);
        if (authnContext == null) {
            return null;
        }

        final DuoOIDCAuthenticationContext duoContext = authnContext.getSubcontext(DuoOIDCAuthenticationContext.class);
        if (duoContext == null) {
            return null;
        }
        
        final DuoOIDCIntegration duoIntegration = duoContext.getIntegration();
        if (duoIntegration == null) {
            return null;
        }
        return duoIntegration.getClientId();
    }

}
